@@ -132,7 +132,7 @@ class PurchaseRequest(metaclass=PoolMeta):
         # delete purchase requests without a purchase line
         products = set(products)
         reqs = cls.search([
-                ('purchase_line', '=', None),
+                ('state', '=', 'draft'),
                 ('origin', 'like', 'stock.order_point,%'),
                 ])
         reqs = [r for r in reqs
@@ -213,7 +213,7 @@ class PurchaseRequest(metaclass=PoolMeta):
     @classmethod
     def get_supply_dates(cls, product, **pattern):
         """
-        Return the minimal interval of earliest supply dates for a product.
+        Return the interval of earliest supply dates for a product.
         """
         Date = Pool().get('ir.date')
 
@@ -223,16 +223,14 @@ class PurchaseRequest(metaclass=PoolMeta):
 
         for product_supplier in product.product_suppliers_used(**pattern):
             supply_date = product_supplier.compute_supply_date(date=today)
+            if supply_date == datetime.date.max:
+                continue
             next_day = today + product_supplier.get_supply_period()
             next_supply_date = product_supplier.compute_supply_date(
                 date=next_day)
             if (not min_date) or supply_date < min_date:
                 min_date = supply_date
-            if (not max_date):
-                max_date = next_supply_date
-            if supply_date > min_date and supply_date < max_date:
-                max_date = supply_date
-            if next_supply_date < max_date:
+            if (not max_date) or next_supply_date > max_date:
                 max_date = next_supply_date
 
         if not min_date:
